@@ -52,8 +52,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.12.1');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2014/4/10');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.12.3');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2014/4/25');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -118,40 +118,52 @@ define('M3_TAG_MACRO_COMMENT_LINK',	'COMMENT_LINK');						// コメントリン
 define('M3_TAG_MACRO_DETAIL_LINK',	'DETAIL_LINK');							// 詳細画面へのリンク置換キー
 define('M3_TAG_MACRO_PERMALINK',	'PERMALINK');							// パーマリンク置換キー
 define('M3_TAG_MACRO_RATE',			'RATE');								// 評価機能置換キー
+define('M3_TAG_MACRO_BUTTON',		'BUTTON');								// ボタン置換キー
 define('M3_TAG_MACRO_WIDGET',		'WIDGET');								// ウィジェット埋め込みキー
 define('M3_TAG_MACRO_SITE_NAME',		'SITE_NAME');						// サイト情報置換キー(サイト名)
 define('M3_TAG_MACRO_SITE_URL',			'SITE_URL');						// サイト情報置換キー(URL)
 define('M3_TAG_MACRO_SITE_DESCRIPTION',	'SITE_DESCRIPTION');				// サイト情報置換キー(簡易説明)
 define('M3_TAG_MACRO_SITE_IMAGE',		'SITE_IMAGE');						// サイト情報置換キー(画像)
-define('M3_TAG_MACRO_CONTENT_BREAK',		'CT_BREAK');					// コンテンツ置換キー(コンテンツ区切り)
-define('M3_TAG_MACRO_CONTENT_ID',			'CT_ID');						// コンテンツ置換キー(コンテンツID)
-define('M3_TAG_MACRO_CONTENT_BLOG_ID',		'CT_BLOG_ID');					// コンテンツ置換キー(ブログID)
-define('M3_TAG_MACRO_CONTENT_NOW',			'CT_NOW');						// コンテンツ置換キー(表示時日時)
-define('M3_TAG_MACRO_CONTENT_DATE',			'CT_DATE');						// コンテンツ置換キー(登録日)
-define('M3_TAG_MACRO_CONTENT_TIME',			'CT_TIME');						// コンテンツ置換キー(登録時)
-define('M3_TAG_MACRO_CONTENT_CREATE_DT',	'CT_CREATE_DT');				// コンテンツ置換キー(作成日時)
-define('M3_TAG_MACRO_CONTENT_UPDATE_DT',	'CT_UPDATE_DT');				// コンテンツ置換キー(更新日時)
-define('M3_TAG_MACRO_CONTENT_REGIST_DT',	'CT_REGIST_DT');				// コンテンツ置換キー(登録日時)
-define('M3_TAG_MACRO_CONTENT_START_DT',		'CT_START_DT');					// コンテンツ置換キー(公開開始日時)
-define('M3_TAG_MACRO_CONTENT_END_DT',		'CT_END_DT');					// コンテンツ置換キー(公開終了日時)
-define('M3_TAG_MACRO_CONTENT_START_TIME',	'CT_START_TIME');				// コンテンツ置換キー(公開開始時間)
-define('M3_TAG_MACRO_CONTENT_END_TIME',		'CT_END_TIME');					// コンテンツ置換キー(公開終了時間)
-define('M3_TAG_MACRO_CONTENT_AUTHOR',		'CT_AUTHOR');					// コンテンツ置換キー(著者)
-define('M3_TAG_MACRO_CONTENT_TITLE',		'CT_TITLE');					// コンテンツ置換キー(タイトル)
-define('M3_TAG_MACRO_CONTENT_BLOG_TITLE',	'CT_BLOG_TITLE');				// コンテンツ置換キー(ブログタイトル)
-define('M3_TAG_MACRO_CONTENT_SUMMARY',		'CT_SUMMARY');					// コンテンツ置換キー(概要)
-define('M3_TAG_MACRO_CONTENT_DESCRIPTION',	'CT_DESCRIPTION');				// コンテンツ置換キー(説明)
-define('M3_TAG_MACRO_CONTENT_URL',			'CT_URL');						// コンテンツ置換キー(URL)
-define('M3_TAG_MACRO_CONTENT_INFO_URL',		'CT_INFO_URL');					// コンテンツ置換キー(その他の情報URL)
-define('M3_TAG_MACRO_CONTENT_IMAGE',		'CT_IMAGE');					// コンテンツ置換キー(画像)
-define('M3_TAG_MACRO_CONTENT_LOCATION',		'CT_LOCATION');					// コンテンツ置換キー(場所)
-define('M3_TAG_MACRO_CONTENT_CONTACT',		'CT_CONTACT');					// コンテンツ置換キー(連絡先)
-define('M3_TAG_MACRO_CONTENT_CAMERA',		'CT_CAMERA');					// コンテンツ置換キー(カメラ)
-define('M3_TAG_MACRO_CONTENT_CATEGORY',		'CT_CATEGORY');					// コンテンツ置換キー(カテゴリー)
-define('M3_TAG_MACRO_CONTENT_KEYWORD',		'CT_KEYWORD');					// コンテンツ置換キー(検索キーワード)
-define('M3_TAG_MACRO_COMMENT_DATE',			'CM_DATE');						// コメント置換キー(登録日)
-define('M3_TAG_MACRO_COMMENT_TIME',			'CM_TIME');						// コメント置換キー(登録時)
-define('M3_TAG_MACRO_COMMENT_AUTHOR',		'CM_AUTHOR');					// コメント置換キー(著者)
+define('M3_TAG_MACRO_CONTENT_BREAK',			'CT_BREAK');					// コンテンツ置換キー(コンテンツ区切り)
+define('M3_TAG_MACRO_CONTENT_ID',				'CT_ID');						// コンテンツ置換キー(コンテンツID)
+define('M3_TAG_MACRO_CONTENT_BLOG_ID',			'CT_BLOG_ID');					// コンテンツ置換キー(ブログID)
+define('M3_TAG_MACRO_CONTENT_NOW',				'CT_NOW');						// コンテンツ置換キー(表示時日時)
+define('M3_TAG_MACRO_CONTENT_DATE',				'CT_DATE');						// コンテンツ置換キー(登録日)
+define('M3_TAG_MACRO_CONTENT_TIME',				'CT_TIME');						// コンテンツ置換キー(登録時)
+define('M3_TAG_MACRO_CONTENT_CREATE_DT',		'CT_CREATE_DT');				// コンテンツ置換キー(作成日時)
+define('M3_TAG_MACRO_CONTENT_UPDATE_DT',		'CT_UPDATE_DT');				// コンテンツ置換キー(更新日時)
+define('M3_TAG_MACRO_CONTENT_REGIST_DT',		'CT_REGIST_DT');				// コンテンツ置換キー(登録日時)
+define('M3_TAG_MACRO_CONTENT_START_DT',			'CT_START_DT');					// コンテンツ置換キー(公開開始日時)
+define('M3_TAG_MACRO_CONTENT_END_DT',			'CT_END_DT');					// コンテンツ置換キー(公開終了日時)
+define('M3_TAG_MACRO_CONTENT_START_TIME',		'CT_START_TIME');				// コンテンツ置換キー(公開開始時間)
+define('M3_TAG_MACRO_CONTENT_END_TIME',			'CT_END_TIME');					// コンテンツ置換キー(公開終了時間)
+define('M3_TAG_MACRO_CONTENT_AUTHOR',			'CT_AUTHOR');					// コンテンツ置換キー(著者)
+define('M3_TAG_MACRO_CONTENT_TITLE',			'CT_TITLE');					// コンテンツ置換キー(タイトル)
+define('M3_TAG_MACRO_CONTENT_BLOG_TITLE',		'CT_BLOG_TITLE');				// コンテンツ置換キー(ブログタイトル)
+define('M3_TAG_MACRO_CONTENT_SUMMARY',			'CT_SUMMARY');					// コンテンツ置換キー(概要)
+define('M3_TAG_MACRO_CONTENT_DESCRIPTION',		'CT_DESCRIPTION');				// コンテンツ置換キー(説明(テキストのみ))
+define('M3_TAG_MACRO_CONTENT_URL',				'CT_URL');						// コンテンツ置換キー(URL)
+define('M3_TAG_MACRO_CONTENT_INFO_URL',			'CT_INFO_URL');					// コンテンツ置換キー(その他の情報URL)
+define('M3_TAG_MACRO_CONTENT_IMAGE',			'CT_IMAGE');					// コンテンツ置換キー(画像)
+define('M3_TAG_MACRO_CONTENT_PLACE',			'CT_PLACE');					// コンテンツ置換キー(場所)
+define('M3_TAG_MACRO_CONTENT_LOCATION',			'CT_LOCATION');					// コンテンツ置換キー(緯度経度)
+define('M3_TAG_MACRO_CONTENT_CONTACT',			'CT_CONTACT');					// コンテンツ置換キー(連絡先)
+define('M3_TAG_MACRO_CONTENT_CAMERA',			'CT_CAMERA');					// コンテンツ置換キー(カメラ)
+define('M3_TAG_MACRO_CONTENT_QUOTA',			'CT_QUOTA');					// コンテンツ置換キー(定員)
+define('M3_TAG_MACRO_CONTENT_ENTRY_COUNT',		'CT_ENTRY_COUNT');				// コンテンツ置換キー(登録数)
+define('M3_TAG_MACRO_CONTENT_CATEGORY',			'CT_CATEGORY');					// コンテンツ置換キー(カテゴリー)
+define('M3_TAG_MACRO_CONTENT_KEYWORD',			'CT_KEYWORD');					// コンテンツ置換キー(検索キーワード)
+define('M3_TAG_MACRO_CONTENT_MEMBER_NAME',		'CT_MEMBER_NAME');				// コンテンツ置換キー(会員名)
+define('M3_TAG_MACRO_CONTENT_MEMBER_ACCOUNT',	'CT_MEMBER_ACCOUNT');			// コンテンツ置換キー(会員アカウント)
+define('M3_TAG_MACRO_CONTENT_MEMBER_EMAIL',		'CT_MEMBER_EMAIL');				// コンテンツ置換キー(会員Eメール)
+define('M3_TAG_MACRO_COMMENT_DATE',				'CM_DATE');						// コメント置換キー(登録日)
+define('M3_TAG_MACRO_COMMENT_TIME',				'CM_TIME');						// コメント置換キー(登録時)
+define('M3_TAG_MACRO_COMMENT_AUTHOR',			'CM_AUTHOR');					// コメント置換キー(著者)
+define('M3_TAG_MACRO_DB_COLUMN',				'DB_COLUMN');					// DBデータ置換キー(カラム値)
+
+// 解析用
+define('M3_PATTERN_TAG_MACRO',				'/' . preg_quote(M3_TAG_START) . '([A-Z0-9_]+)\|?(.*?)' . preg_quote(M3_TAG_END) . '/u');							// システムマクロパターン
+define('M3_PATTERN_TAG_MACRO_USER_KEY',		'/' . preg_quote(M3_TAG_START . M3_TAG_MACRO_USER_KEY) . '([A-Z0-9_]+)\|?(.*?)' . preg_quote(M3_TAG_END) . '/u');	// ユーザ定義マクロパターン
 
 // イベントフックタイプ
 define('M3_EVENT_HOOK_TYPE_OPELOG',			'opelog');						// 運用ログ
@@ -161,8 +173,12 @@ define('M3_EVENT_HOOK_PARAM_CONTENT_ID',	'content_id');					// コンテンツID
 define('M3_EVENT_HOOK_PARAM_UPDATE_DT',		'update_dt');					// 更新日時
 
 // データ作成用
-define('M3_WIDGET_ID_SEPARATOR',	',');									// ウィジェットIDと付加情報を連結
-define('M3_LANG_SEPARATOR',			'|');									// 言語IDと内容を連結
+define('M3_WIDGET_ID_SEPARATOR',		',');									// ウィジェットIDと付加情報を連結
+//define('M3_LANG_SEPARATOR',				'|');									// 言語IDと内容を連結
+define('M3_LANG_SEPARATOR',				"\t");									// 言語IDと内容を連結
+define('M3_MACRO_SEPARATOR',			'|');									// マクロキーと値を連結(変更予定)
+//define('M3_MACRO_SEPARATOR',			"\t");									// マクロキーと値を連結
+define('M3_MACRO_OPTION_SEPARATOR',		'|');									// マクロキーとオプションを連結
 
 // テンプレートタイプ
 define('M3_TEMPLATE_JOOMLA_10',			0);		// Joomla!v1.0テンプレート
@@ -203,7 +219,6 @@ define('M3_VIEW_TYPE_SEARCH',		'search');				// 検索結果
 define('M3_VIEW_TYPE_COMMERCE',		'commerce');			// Eコマース
 define('M3_VIEW_TYPE_CALENDAR',		'calendar');			// カレンダー
 // コンテンツタイプ
-define('M3_VIEW_TYPE_NEWS',			'news');				// 新着情報
 define('M3_VIEW_TYPE_MEMBER',		'member');				// 会員情報
 define('M3_VIEW_TYPE_CONTENT',		'content');				// 汎用コンテンツ
 define('M3_VIEW_TYPE_PRODUCT',		'product');				// 商品情報
@@ -213,6 +228,12 @@ define('M3_VIEW_TYPE_WIKI',			'wiki');				// Wiki
 define('M3_VIEW_TYPE_USER',			'user');				// ユーザ作成コンテンツ
 define('M3_VIEW_TYPE_EVENT',		'event');				// イベント情報
 define('M3_VIEW_TYPE_PHOTO',		'photo');				// フォトギャラリー
+// 補助コンテンツ
+define('M3_VIEW_TYPE_NEWS',			'news');				// 新着情報
+define('M3_VIEW_TYPE_COMMENT',		'comment');				// コメント
+define('M3_VIEW_TYPE_EVENTENTRY',	'evententry');			// イベント予約
+define('M3_VIEW_TYPE_BANNER',		'banner');				// バナー
+
 // すべての機能タイプ
 $M3_ALL_FEATURE_TYPE	= array(	M3_VIEW_TYPE_DASHBOARD,			// ダッシュボード
 									M3_VIEW_TYPE_SEARCH,			// 検索結果
@@ -228,6 +249,7 @@ $M3_ALL_CONTENT_TYPE	= array(	M3_VIEW_TYPE_NEWS,				// 新着情報
 									M3_VIEW_TYPE_WIKI,				// Wiki
 									M3_VIEW_TYPE_USER,				// ユーザ作成コンテンツ
 									M3_VIEW_TYPE_EVENT,				// イベント情報
+									M3_VIEW_TYPE_EVENTENTRY,		// イベント予約
 									M3_VIEW_TYPE_PHOTO);			// フォトギャラリー
 
 // コンテンツ取得用キー
@@ -317,6 +339,7 @@ define('M3_REQUEST_PARAM_CATEGORY_ID',      		'categoryid');		// カテゴリID(
 define('M3_REQUEST_PARAM_WIDTH',      				'width');			// 幅
 define('M3_REQUEST_PARAM_HEIGHT',      				'height');			// 高さ
 define('M3_REQUEST_PARAM_COMMENT_ID',      			'commentid');		// コメント識別用ID
+define('M3_REQUEST_PARAM_PLACE_ID',      			'placeid');			// 場所識別用ID
 define('M3_REQUEST_PARAM_CONTENT_ID',      			'contentid');		// 汎用コンテンツID
 define('M3_REQUEST_PARAM_CONTENT_ID_SHORT',      	'cid');				// 汎用コンテンツID(略式)
 define('M3_REQUEST_PARAM_PRODUCT_ID',      			'productid');		// 製品ID
