@@ -31,6 +31,8 @@ class TextConvManager extends Core
 	const DEFAULT_MOBILE_IMAGE_HEIGHT = 320;	// 携帯用画像のデフォルトサイズ(高さ)
 	const DEFAULT_MOBILE_IMAGE_FILE_EXT = 'gif';		// 携帯用画像の形式
 	const CONTENT_MACRO_OPTION_SEPARATOR = ';';			// コンテンツマクロのオプション設定の区切り
+	const NO_DATA_DISP_LABEL = '名称未設定';			// データがない場合の表示ラベル
+	const NO_TIME_DATA_DISP_LABEL = '名称未設定';			// 時間データがない場合の表示ラベル
 	
 	/**
 	 * コンストラクタ
@@ -86,7 +88,8 @@ class TextConvManager extends Core
 	function parseUserMacro($src)
 	{
 		$fields = array();
-		$pattern = '/' . preg_quote(M3_TAG_START . M3_TAG_MACRO_USER_KEY) . '([A-Z0-9_]+):?(.*?)' . preg_quote(M3_TAG_END) . '/u';
+//		$pattern = '/' . preg_quote(M3_TAG_START . M3_TAG_MACRO_USER_KEY) . '([A-Z0-9_]+):?(.*?)' . preg_quote(M3_TAG_END) . '/u';
+		$pattern = '/' . preg_quote(M3_TAG_START . M3_TAG_MACRO_USER_KEY) . '([A-Z0-9_]+)\|?(.*?)' . preg_quote(M3_TAG_END) . '/u';	// オプションパラメータは「|」以降(2015/4/20変更)
 		
 		if (is_array($src)){
 			for ($j = 0; $j < count($src); $j++){
@@ -126,7 +129,8 @@ class TextConvManager extends Core
 		$this->htmlEscapedValue = $htmlEscapedValue;	// 変換後の値をHTMLエスケープ処理するかどうか
 		
 		// Magic3マクロを検索(「[#」と「#]」で区切られた文字列)
-		$pattern = '/' . preg_quote(M3_TAG_START) . '([A-Z0-9_]+):?(.*?)' . preg_quote(M3_TAG_END) . '/u';
+		//$pattern = '/' . preg_quote(M3_TAG_START) . '([A-Z0-9_]+):?(.*?)' . preg_quote(M3_TAG_END) . '/u';
+		$pattern = '/' . preg_quote(M3_TAG_START) . '([A-Z0-9_]+)\|?(.*?)' . preg_quote(M3_TAG_END) . '/u';			// オプションパラメータは「|」以降(2015/4/20変更)
 		$dest = preg_replace_callback($pattern, array($this, '_replace_content_macro_callback'), $src);
 		return $dest;
 	}
@@ -142,6 +146,7 @@ class TextConvManager extends Core
 		global $gInstanceManager;
 		global $gEnvManager;
 		global $gPageManager;
+		global $gDesignManager;
 		static $keyValues;
 
 		$htmlEscaped = false;			// HTMLエスケープ終了かどうか
@@ -171,54 +176,63 @@ class TextConvManager extends Core
 				case 'CT_UPDATE_DT':			// コンテンツ更新日時
 				case 'CT_REGIST_DT':			// コンテンツ登録日時
 					$value = $this->contentInfo[$typeTag];
-					if (isset($value)){
-						if (empty($value)){
-							$destTag = $value;
+					if (!isset($value)) $value = self::NO_TIME_DATA_DISP_LABEL;		// 未設定の場合は時間データなしの表示ラベルを設定
+					
+					if (empty($value)){
+						$destTag = '';		// 出力をクリア
+					} else {
+						if (empty($options)){
+							$destTag = date(M3_VIEW_FORMAT_DATETIME, strtotime($value));
 						} else {
-							if (empty($options)){
-								$destTag = date(M3_VIEW_FORMAT_DATETIME, strtotime($value));
-							} else {
-								$destTag = date($options, strtotime($value));
-							}
+							$destTag = date($options, strtotime($value));
 						}
 					}
 					break;
 				case 'CT_DATE':					// コンテンツ登録日
 					$value = $this->contentInfo[$typeTag];
-					if (isset($value)){
-						if (empty($value)){
-							$destTag = $value;
+					if (!isset($value)) $value = self::NO_TIME_DATA_DISP_LABEL;		// 未設定の場合は時間データなしの表示ラベルを設定
+					
+					if (empty($value)){
+						$destTag = '';	// 出力をクリア
+					} else {
+						if (empty($options)){
+							$destTag = date(M3_VIEW_FORMAT_DATE, strtotime($value));
 						} else {
-							if (empty($options)){
-								$destTag = date(M3_VIEW_FORMAT_DATE, strtotime($value));
-							} else {
-								$destTag = date($options, strtotime($value));
-							}
+							$destTag = date($options, strtotime($value));
 						}
 					}
 					break;
 				case 'CT_TIME':					// コンテンツ登録時
 					$value = $this->contentInfo[$typeTag];
-					if (isset($value)){
-						if (empty($value)){
-							$destTag = $value;
+					if (!isset($value)) $value = self::NO_TIME_DATA_DISP_LABEL;		// 未設定の場合は時間データなしの表示ラベルを設定
+					
+					if (empty($value)){
+						$destTag = '';	// 出力をクリア
+					} else {
+						if (empty($options)){
+							$destTag = date(M3_VIEW_FORMAT_TIME, strtotime($value));
 						} else {
-							if (empty($options)){
-								$destTag = date(M3_VIEW_FORMAT_TIME, strtotime($value));
-							} else {
-								$destTag = date($options, strtotime($value));
-							}
+							$destTag = date($options, strtotime($value));
 						}
 					}
 					break;
 				case 'CT_ID':		// コンテンツID
 				case 'CT_TITLE':		// コンテンツタイトル
 				default:
-					$optionParams = $this->_parseContentMacroOption($options);
+					// コンテンツマクロオプションを解析
+					$optionParams = $this->parseMacroOption($options);
+					
+					// 置き換える文字列を取得
 					$value = $this->contentInfo[$typeTag];
-					if (isset($value)){
+					if (!isset($value)) $value = self::NO_DATA_DISP_LABEL;		// 未設定の場合はデータなしの表示ラベルを設定
+
+					if (empty($value)){
+						$destTag = '';	// 出力をクリア
+					} else {
 						$destTag = $value;
-						
+					
+						// コンテンツマクロオプション処理
+						// コンテンツマクロオプションはHTMLエスケープ($this->htmlEscapedValue)しない場合でも強制的に処理を行う。
 						$keys = array_keys($optionParams);
 						for ($i = 0; $i < count($keys); $i++){
 							$optionKey = $keys[$i];
@@ -235,6 +249,16 @@ class TextConvManager extends Core
 					}
 					break;
 			}
+			// リンク用URLが設定されている場合はリンクを作成(フォーマット「リンク元文字列|リンク先URL」の場合)
+			if (!$htmlEscaped && !empty($destTag)){
+				if ($this->htmlEscapedValue){		// HTMLエスケープ処理する場合
+					$destTag = $gDesignManager->createLinkFromLinkFomatText($destTag, true/*HTMLエスケープあり*/);
+					$htmlEscaped = true;			// HTMLエスケープ終了かどうか
+				} else {
+					// リンク元文字列のみ返る
+					$destTag = $gDesignManager->createLinkFromLinkFomatText($destTag, false/*HTMLエスケープなし*/);
+				}
+			}
 		} else if (strStartsWith($typeTag, M3_TAG_MACRO_COMMENT_KEY)){		// コメント置換キー
 			switch ($typeTag){
 				case 'CM_DATE':					// コメント登録日
@@ -294,12 +318,12 @@ class TextConvManager extends Core
 		return $destTag;
 	}
 	/**
-	 * コンテンツマクロオプションを解析
+	 * マクロオプションを解析
 	 *
 	 * @param string $src		変換するデータ
 	 * @return array			オプションパラメータ
 	 */
-	function _parseContentMacroOption($src)
+	function parseMacroOption($src)
 	{
 		$options = array();
 		$itemArray = explode(self::CONTENT_MACRO_OPTION_SEPARATOR, strtolower(trim($src)));// 小文字に変換したものを解析
@@ -1212,5 +1236,26 @@ class TextConvManager extends Core
 	function _trim_search_keyword($src){
 		return trim($src, "\"'\n\r ");
 	}
+	/**
+	 * 文字列からリンク対象とリンク先URLを取得
+	 *
+	 * @param string $str		解析文字列
+	 * @return array			リンク対象語文字列とリンク先URL
+	 */
+/*	function _parseLinkString($str)
+	{
+		$destStr = '';
+		$url = '';
+		
+		// リンク元文字列を取得
+		$pos = strpos($str, '|');
+		if ($pos === false){
+			$destStr = $str;
+		} else {
+			list($destStr, $url) = explode('|', $str, 2);
+		}
+			
+		return array($destStr, $url);
+	}*/
 }
 ?>
