@@ -25,7 +25,29 @@ UPDATE _page_id SET pg_default_sub_id = 'wiki' WHERE pg_id = 'index' AND pg_type
 -- スマートフォン,携帯のアクセスポイントを隠す
 UPDATE _page_id SET pg_active = false WHERE pg_id = 's_index' AND pg_type = 0;
 UPDATE _page_id SET pg_active = false WHERE pg_id = 'm_index' AND pg_type = 0;
-
+-- 必要なページのみ表示
+DELETE FROM _page_id WHERE pg_type = 1;
+INSERT INTO _page_id 
+(pg_id,          pg_type,      pg_name,                            pg_description,                       pg_priority, pg_active, pg_visible, pg_editable, pg_available) VALUES
+('front',        1,            'トップ画面',                       'トップ画面用',                       0,           true,      true,       true,        true),
+('content',      1,            'コンテンツ',                       'コンテンツ画面用',                   1,           true,      true,       false,       true),
+('shop',         1,            'ECショップ',                       'ECショップ画面用',                   2,           true,      true,       true,        false),
+('shop_safe',    1,            'ECショップ(セキュリティ保護)',     'ECショップ(セキュリティ保護)画面用', 3,           true,      true,       true,        false),
+('bbs',          1,            '掲示板',                           '掲示板画面用',                       4,           true,      true,       true,        false),
+('blog',         1,            'ブログ',                           'ブログ画面用',                       5,           true,      true,       true,        false),
+('wiki',         1,            'Wiki',                             'Wiki画面用',                         6,           true,      true,       true,        true),
+('calendar',     1,            'カレンダー',                       'カレンダー画面用',                   7,           true,      true,       true,        false),
+('event',        1,            'イベント情報',                     'イベント情報画面用',                 8,           true,      true,       true,        false),
+('photo',        1,            'フォトギャラリー',                 'フォトギャラリー画面用',             9,           true,      true,       true,        false),
+('contact',      1,            'お問い合わせ',                     'お問い合わせ画面用',                 10,          true,      true,       true,        true),
+('contact2',     1,            'お問い合わせ2',                    'お問い合わせ画面用',                 11,          true,      true,       true,        false),
+('reguser',      1,            'ユーザ登録',                       'ユーザ登録画面用',                   12,          true,      true,       true,        false),
+('reserve',      1,            '予約',                             '予約画面用',                         19,          true,      true,       true,        false),
+('member',       1,            '会員',                             '会員画面用',                         20,          true,      true,       true,        false),
+('search',       1,            '検索',                             '検索画面用',                         21,          true,      true,       true,        true),
+('user',         1,            'ユーザコンテンツ',                 'ユーザ作成コンテンツ用',             50,          true,      true,       true,        false),
+('deploy',       1,            'ウィジェット有効化用',             'ウィジェット有効化用',               100,         true,      false,      true,        false),
+('test',         1,            'ウィジェットテスト用',             'ウィジェットテスト用非公開画面',     101,         false,     true,       true,        false);
 
 -- 管理画面メニューデータ
 DELETE FROM _nav_item;
