@@ -561,7 +561,8 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 	{
 		$menuItems = array(array(), array(), array());
 		$pageIdArray = array($this->gEnv->getDefaultPageId(), $this->gEnv->getDefaultMobilePageId(), $this->gEnv->getDefaultSmartphonePageId());
-		$ret = $this->db->getEditSubWidgetOnPage($pageIdArray, $rows);
+		$contentType = $this->gPage->getSubContentTypes();
+		$ret = $this->db->getEditSubWidgetOnPage($pageIdArray, $contentType, $rows);
 		if ($ret){
 			$rowCount = count($rows);
 			for ($i = 0; $i < $rowCount; $i++){
@@ -593,6 +594,8 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 	function createContentMenu($deviceType, $isVisibleSite)
 	{
 		static $mainContentTypeArray;
+		static $subContentTypeArray;
+		static $mainFeatureTypeArray;
 		
 		if (!isset($mainContentTypeArray)){
 			$mainContentTypeArray = array();
@@ -603,6 +606,24 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 				$mainContentTypeArray[$value] = $name;
 			}
 		}
+		if (!isset($subContentTypeArray)){
+			$subContentTypeArray = array();
+			$subContentTypeInfo = $this->gPage->getSubContentTypeInfo();		// 補助コンテンツタイプ情報
+			for ($i = 0; $i < count($subContentTypeInfo); $i++){
+				$value = $subContentTypeInfo[$i]['value'];
+				$name = $subContentTypeInfo[$i]['name'];
+				$subContentTypeArray[$value] = $name;
+			}
+		}
+		if (!isset($mainFeatureTypeArray)){
+			$mainFeatureTypeArray = array();
+			$mainFeatureTypeInfo = $this->gPage->getMainFeatureTypeInfo();		// 主要機能タイプ情報
+			for ($i = 0; $i < count($mainFeatureTypeInfo); $i++){
+				$value = $mainFeatureTypeInfo[$i]['value'];
+				$name = $mainFeatureTypeInfo[$i]['name'];
+				$mainFeatureTypeArray[$value] = $name;
+			}
+		}
 
 		$menuTag = '';
 		$menu = $this->contentMenu[$deviceType];		// コンテンツ編集メニュー
@@ -702,17 +723,22 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 				if (empty($title)){
 					// コンテンツ単位でタイトルを取得
 					$contentType = $subMenu[$i]['wd_content_type'];
-					switch ($contentType){
+					$title = $subContentTypeArray[$contentType];
+					if (empty($title)) $title = $mainFeatureTypeArray[$contentType];
+/*					switch ($contentType){
 						case 'banner':				// バナー
 							$title = 'バナー';
 							break;
 						case 'news':				// 新着情報
 							$title = '新着情報';
 							break;
+						case 'evententry':				// イベント予約
+							$title = 'イベント予約';
+							break;
 						default:
 							$title = '';
 							break;
-					}
+					}*/
 				}
 				if (empty($title)) $title = $subMenu[$i]['wd_name'];		// サブコンテンツ名が取得できないときはウィジェット名を設定
 				if (empty($title)) continue;
